@@ -2,8 +2,10 @@
 """Manage MLS application client components."""
 
 from fabric import api
-from mls.fabfile import rackspace, utils
-from mls.fabfile.exceptions import missing_env
+from mls.fabfile.utils import mls_config
+from propertyshelf.fabfile.common import rackspace
+from propertyshelf.fabfile.common import utils
+from propertyshelf.fabfile.common.exceptions import missing_env
 
 
 @api.task
@@ -23,8 +25,8 @@ def remove():
 def update():
     """Update the client packages."""
     utils.supervisorctl(command='stop', service='application')
-    utils.backup_dev_packages()
-    utils.run_buildout()
+    utils.backup_dev_packages(config=mls_config())
+    utils.run_buildout(config=mls_config())
     utils.supervisorctl(command='start', service='application')
 
 
@@ -33,3 +35,11 @@ def update():
 def restart():
     """Restart the application client component."""
     utils.supervisorctl(command='restart', service='application')
+
+
+@api.task
+@api.roles('worker')
+def rebuild():
+    """Rebuild the application using buildout."""
+    utils.run_buildout(config=mls_config())
+    utils.supervisorctl(command='restart', service='application')
